@@ -1,12 +1,13 @@
 use std::io::{Read, Result, Seek, SeekFrom};
+use std::marker::Sync;
 
 use symphonia::core::io::MediaSource;
 
-pub struct ReadSeekSource<T: Read + Seek + Send> {
+pub struct ReadSeekSource<T: Read + Seek + Send + Sync> {
     inner: T,
 }
 
-impl<T: Read + Seek + Send> ReadSeekSource<T> {
+impl<T: Read + Seek + Send + Sync> ReadSeekSource<T> {
     /// Instantiates a new `ReadSeekSource<T>` by taking ownership and wrapping the provided
     /// `Read + Seek`er.
     pub fn new(inner: T) -> Self {
@@ -14,7 +15,7 @@ impl<T: Read + Seek + Send> ReadSeekSource<T> {
     }
 }
 
-impl<T: Read + Seek + Send> MediaSource for ReadSeekSource<T> {
+impl<T: Read + Seek + Send + Sync> MediaSource for ReadSeekSource<T> {
     fn is_seekable(&self) -> bool {
         true
     }
@@ -24,13 +25,13 @@ impl<T: Read + Seek + Send> MediaSource for ReadSeekSource<T> {
     }
 }
 
-impl<T: Read + Seek + Send> Read for ReadSeekSource<T> {
+impl<T: Read + Seek + Send + Sync> Read for ReadSeekSource<T> {
     fn read(&mut self, buf: &mut [u8]) -> Result<usize> {
         self.inner.read(buf)
     }
 }
 
-impl<T: Read + Seek + Send> Seek for ReadSeekSource<T> {
+impl<T: Read + Seek + Send + Sync> Seek for ReadSeekSource<T> {
     fn seek(&mut self, pos: SeekFrom) -> Result<u64> {
         self.inner.seek(pos)
     }
