@@ -1,8 +1,4 @@
 #![cfg_attr(test, deny(missing_docs))]
-pub use cpal::{
-    self, traits::DeviceTrait, Device, Devices, DevicesError, InputDevices, OutputDevices,
-    SupportedStreamConfig,
-};
 
 mod conversions;
 mod sink;
@@ -15,6 +11,10 @@ pub mod queue;
 pub mod source;
 
 pub use conversions::Sample;
+pub use cpal::{
+    self, traits::DeviceTrait, Device, Devices, DevicesError, InputDevices, OutputDevices,
+    SupportedStreamConfig,
+};
 pub use decoder::Decoder;
 pub use sink::Sink;
 pub use source::Source;
@@ -64,8 +64,10 @@ impl Player {
     pub fn change_volume(&mut self, positive: bool) {
         if positive {
             self.volume += VOLUME_STEP;
-        } else if self.volume != 0 {
+        } else if self.volume >= VOLUME_STEP {
             self.volume -= VOLUME_STEP;
+        } else {
+            self.volume = 0;
         }
 
         if self.volume > 100 {
@@ -103,39 +105,46 @@ impl Player {
         self.sink.is_paused()
     }
     pub fn seek_fw(&mut self) {
-        let seek = self.elapsed().as_secs_f64() + 5.0;
+        let new_pos = self.elapsed().as_secs_f64() + 5.0;
         if let Some(duration) = self.duration() {
-            if seek > duration {
+            if new_pos > duration {
                 self.safe_guard = true;
             } else {
-                self.seek_to(Duration::from_secs_f64(seek));
+                self.seek_to(Duration::from_secs_f64(new_pos));
             }
         }
     }
     pub fn seek_bw(&mut self) {
-        let mut seek = self.elapsed().as_secs_f64() - 5.0;
-        if seek < 0.0 {
-            seek = 0.0;
+        let mut new_pos = self.elapsed().as_secs_f64() - 5.0;
+        if new_pos < 0.0 {
+            new_pos = 0.0;
         }
 
-        self.seek_to(Duration::from_secs_f64(seek));
+        self.seek_to(Duration::from_secs_f64(new_pos));
     }
     pub fn seek_to(&self, time: Duration) {
         self.sink.seek(time);
     }
-    pub fn seeker(&self) -> f64 {
+    pub fn percentage(&self) -> f64 {
         self.duration().map_or(0.0, |duration| {
             let elapsed = self.elapsed();
             elapsed.as_secs_f64() / duration
         })
     }
     pub fn trigger_next(&mut self) -> bool {
+        // //TODO: duration is broken for certain files
+        // //This will cause songs to play forever
+        // if duration == -0.29 {
+        //     return false;
+        // }
         if let Some(duration) = self.duration() {
             if self.elapsed().as_secs_f64() > duration {
                 self.safe_guard = true;
             }
         }
 
+        // dbg!(self.safe_guard);
+
         if self.safe_guard {
             self.safe_guard = false;
             true
@@ -209,7 +218,7 @@ impl GeneralP for Player {
     fn get_progress(&mut self) -> Result<(f64, i64, i64)> {
         let position = self.elapsed().as_secs() as i64;
         let duration = self.duration().unwrap_or(99.0) as i64;
-        let mut percent = self.seeker() * 100.0;
+        let mut percent = self.percentage() * 100.0;
         if percent > 100.0 {
             percent = 100.0;
         }
