@@ -1,5 +1,4 @@
-use crate::config::Keys;
-use crate::ui::components::StyleColorSymbol;
+use crate::ui::components::{Keys, StyleColorSymbol};
 use crate::ui::model::MAX_DEPTH;
 use crate::ui::{Id, LIMsg, Model, Msg, TEMsg, YSMsg};
 use anyhow::{bail, Result};
@@ -59,10 +58,17 @@ impl Component<Msg, NoUserEvent> for MusicLibrary {
     #[allow(clippy::too_many_lines)]
     fn on(&mut self, ev: Event<NoUserEvent>) -> Option<Msg> {
         let result = match ev {
-            Event::Keyboard(key) if key == self.keys.vim_h => {
+            Event::Keyboard(keyevent) if keyevent == self.keys.global_left.key_event() => {
                 self.perform(Cmd::Custom(TREE_CMD_CLOSE))
             }
-            Event::Keyboard(key) if key == self.keys.vim_l => {
+            Event::Keyboard(KeyEvent {
+                code: Key::Left,
+                modifiers: KeyModifiers::NONE,
+            }) => self.perform(Cmd::Custom(TREE_CMD_CLOSE)),
+            Event::Keyboard(KeyEvent {
+                code: Key::Right,
+                modifiers: KeyModifiers::NONE,
+            }) => {
                 let current_node = self.component.tree_state().selected().unwrap();
                 let p: &Path = Path::new(current_node);
                 if p.is_dir() {
@@ -73,17 +79,33 @@ impl Component<Msg, NoUserEvent> for MusicLibrary {
                     )));
                 }
             }
-            Event::Keyboard(key) if key == self.keys.vim_j => {
+            Event::Keyboard(keyevent) if keyevent == self.keys.global_right.key_event() => {
+                let current_node = self.component.tree_state().selected().unwrap();
+                let p: &Path = Path::new(current_node);
+                if p.is_dir() {
+                    self.perform(Cmd::Custom(TREE_CMD_OPEN))
+                } else {
+                    return Some(Msg::Playlist(crate::ui::PLMsg::Add(
+                        current_node.to_string(),
+                    )));
+                }
+            }
+            Event::Keyboard(keyevent) if keyevent == self.keys.global_down.key_event() => {
                 self.perform(Cmd::Move(Direction::Down))
             }
-            Event::Keyboard(key) if key == self.keys.vim_k => {
+            Event::Keyboard(keyevent) if keyevent == self.keys.global_up.key_event() => {
                 self.perform(Cmd::Move(Direction::Up))
             }
-
             Event::Keyboard(KeyEvent {
-                code: Key::Right | Key::Char('L'),
-                modifiers: KeyModifiers::SHIFT,
-            }) => {
+                code: Key::Down,
+                modifiers: KeyModifiers::NONE,
+            }) => self.perform(Cmd::Move(Direction::Down)),
+            Event::Keyboard(KeyEvent {
+                code: Key::Up,
+                modifiers: KeyModifiers::NONE,
+            }) => self.perform(Cmd::Move(Direction::Up)),
+
+            Event::Keyboard(keyevent) if keyevent == self.keys.library_load_dir.key_event() => {
                 let current_node = self.component.tree_state().selected().unwrap();
                 let p: &Path = Path::new(current_node);
                 if p.is_dir() {
@@ -101,14 +123,12 @@ impl Component<Msg, NoUserEvent> for MusicLibrary {
                 code: Key::PageUp,
                 modifiers: KeyModifiers::NONE,
             }) => self.perform(Cmd::Scroll(Direction::Up)),
-            Event::Keyboard(KeyEvent {
-                code: Key::Home | Key::Char('g'),
-                modifiers: KeyModifiers::NONE,
-            }) => self.perform(Cmd::GoTo(Position::Begin)),
-            Event::Keyboard(KeyEvent {
-                code: Key::End | Key::Char('G'),
-                modifiers: KeyModifiers::SHIFT,
-            }) => self.perform(Cmd::GoTo(Position::End)),
+            Event::Keyboard(keyevent) if keyevent == self.keys.global_goto_top.key_event() => {
+                self.perform(Cmd::GoTo(Position::Begin))
+            }
+            Event::Keyboard(keyevent) if keyevent == self.keys.global_goto_bottom.key_event() => {
+                self.perform(Cmd::GoTo(Position::End))
+            }
             Event::Keyboard(KeyEvent {
                 code: Key::Enter,
                 modifiers: KeyModifiers::NONE,
@@ -121,30 +141,26 @@ impl Component<Msg, NoUserEvent> for MusicLibrary {
                 code: Key::Tab,
                 modifiers: KeyModifiers::NONE,
             }) => return Some(Msg::Library(LIMsg::TreeBlur)),
-            Event::Keyboard(KeyEvent {
-                code: Key::Char('d'),
-                ..
-            }) => return Some(Msg::DeleteConfirmShow),
-            Event::Keyboard(KeyEvent {
-                code: Key::Char('y'),
-                ..
-            }) => return Some(Msg::Library(LIMsg::Yank)),
-            Event::Keyboard(KeyEvent {
-                code: Key::Char('p'),
-                ..
-            }) => return Some(Msg::Library(LIMsg::Paste)),
-            Event::Keyboard(KeyEvent {
-                code: Key::Char('/'),
-                ..
-            }) => return Some(Msg::GeneralSearch(crate::ui::GSMsg::PopupShowLibrary)),
-            Event::Keyboard(KeyEvent {
-                code: Key::Char('s'),
-                modifiers: KeyModifiers::NONE,
-            }) => return Some(Msg::YoutubeSearch(YSMsg::InputPopupShow)),
-            Event::Keyboard(KeyEvent {
-                code: Key::Char('t'),
-                modifiers: KeyModifiers::NONE,
-            }) => {
+            Event::Keyboard(keyevent) if keyevent == self.keys.library_delete.key_event() => {
+                return Some(Msg::DeleteConfirmShow)
+            }
+            Event::Keyboard(keyevent) if keyevent == self.keys.library_yank.key_event() => {
+                return Some(Msg::Library(LIMsg::Yank))
+            }
+            Event::Keyboard(keyevent) if keyevent == self.keys.library_paste.key_event() => {
+                return Some(Msg::Library(LIMsg::Paste))
+            }
+            Event::Keyboard(keyevent) if keyevent == self.keys.library_search.key_event() => {
+                return Some(Msg::GeneralSearch(crate::ui::GSMsg::PopupShowLibrary))
+            }
+            Event::Keyboard(keyevent)
+                if keyevent == self.keys.library_search_youtube.key_event() =>
+            {
+                return Some(Msg::YoutubeSearch(YSMsg::InputPopupShow))
+            }
+            Event::Keyboard(keyevent)
+                if keyevent == self.keys.library_tag_editor_open.key_event() =>
+            {
                 let current_node = self.component.tree_state().selected().unwrap();
                 return Some(Msg::TagEditor(TEMsg::TagEditorRun(
                     current_node.to_string(),
@@ -233,10 +249,16 @@ impl Model {
         };
         // Remount tree
         // keep focus
-        let mut focus = false;
+        let mut focus_library = false;
         if let Ok(f) = self.app.query(&Id::Library, Attribute::Focus) {
             if Some(AttrValue::Flag(true)) == f {
-                focus = true;
+                focus_library = true;
+            }
+        }
+        let mut focus_playlist = false;
+        if let Ok(f) = self.app.query(&Id::Playlist, Attribute::Focus) {
+            if Some(AttrValue::Flag(true)) == f {
+                focus_playlist = true;
             }
         }
 
@@ -254,9 +276,15 @@ impl Model {
                 Vec::new()
             )
             .is_ok());
-        if focus {
+        if focus_library {
             assert!(self.app.active(&Id::Library).is_ok());
+            return;
         }
+        if focus_playlist {
+            return;
+        }
+
+        assert!(self.app.active(&Id::Library).is_ok());
     }
 
     pub fn library_stepinto(&mut self, node_id: &str) {
